@@ -1,7 +1,7 @@
 from enum import Enum
 
 
-class StatsigEnvironmentTier(Enum):
+class StatsigEnvironmentTier(str, Enum):
     """
     The environment tier the SDK is running in.
     Used to view data in the Statsig console by tier
