@@ -32,15 +32,24 @@ class _OutputLogger(Logger):
         self._logs[process].append(message)
 
     def debug(self, msg, *args, **kwargs):
-        self._logs["debug"].append(msg % args)
+        formatted = msg
+        if args:
+            formatted = msg % args
+        self._logs["debug"].append(formatted)
         super().debug(msg, *args, **kwargs)
 
     def info(self, msg, *args, **kwargs):
-        self._logs["info"].append(msg % args)
+        formatted = msg
+        if args:
+            formatted = msg % args
+        self._logs["info"].append(formatted)
         super().info(msg, *args, **kwargs)
 
     def warning(self, msg, *args, **kwargs):
-        self._logs["warning"].append(msg % args)
+        formatted = msg
+        if args:
+            formatted = msg % args
+        self._logs["warning"].append(formatted)
         super().warning(msg, *args, **kwargs)
 
     def clear_log_history(self):
